/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/codecommit/CodeCommitRequest.h>
#include <aws/codecommit/CodeCommit_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
namespace CodeCommit {
namespace Model {

/**
 * <p>Represents the input of a batch get repositories operation.</p><p><h3>See
 * Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/codecommit-2015-04-13/BatchGetRepositoriesInput">AWS
 * API Reference</a></p>
 */
class BatchGetRepositoriesRequest : public CodeCommitRequest {
 public:
  AWS_CODECOMMIT_API BatchGetRepositoriesRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "BatchGetRepositories"; }

  AWS_CODECOMMIT_API Aws::String SerializePayload() const override;

  AWS_CODECOMMIT_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>The names of the repositories to get information about.</p>  <p>The
   * length constraint limit is for each string in the array. The array itself can be
   * empty.</p>
   */
  inline const Aws::Vector<Aws::String>& GetRepositoryNames() const { return m_repositoryNames; }
  inline bool RepositoryNamesHasBeenSet() const { return m_repositoryNamesHasBeenSet; }
  template <typename RepositoryNamesT = Aws::Vector<Aws::String>>
  void SetRepositoryNames(RepositoryNamesT&& value) {
    m_repositoryNamesHasBeenSet = true;
    m_repositoryNames = std::forward<RepositoryNamesT>(value);
  }
  template <typename RepositoryNamesT = Aws::Vector<Aws::String>>
  BatchGetRepositoriesRequest& WithRepositoryNames(RepositoryNamesT&& value) {
    SetRepositoryNames(std::forward<RepositoryNamesT>(value));
    return *this;
  }
  template <typename RepositoryNamesT = Aws::String>
  BatchGetRepositoriesRequest& AddRepositoryNames(RepositoryNamesT&& value) {
    m_repositoryNamesHasBeenSet = true;
    m_repositoryNames.emplace_back(std::forward<RepositoryNamesT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<Aws::String> m_repositoryNames;
  bool m_repositoryNamesHasBeenSet = false;
};

}  // namespace Model
}  // namespace CodeCommit
}  // namespace Aws
