/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/cleanroomsml/CleanRoomsML_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace CleanRoomsML {
namespace Model {
class GetConfiguredAudienceModelPolicyResult {
 public:
  AWS_CLEANROOMSML_API GetConfiguredAudienceModelPolicyResult() = default;
  AWS_CLEANROOMSML_API GetConfiguredAudienceModelPolicyResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_CLEANROOMSML_API GetConfiguredAudienceModelPolicyResult& operator=(
      const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The Amazon Resource Name (ARN) of the configured audience model.</p>
   */
  inline const Aws::String& GetConfiguredAudienceModelArn() const { return m_configuredAudienceModelArn; }
  template <typename ConfiguredAudienceModelArnT = Aws::String>
  void SetConfiguredAudienceModelArn(ConfiguredAudienceModelArnT&& value) {
    m_configuredAudienceModelArnHasBeenSet = true;
    m_configuredAudienceModelArn = std::forward<ConfiguredAudienceModelArnT>(value);
  }
  template <typename ConfiguredAudienceModelArnT = Aws::String>
  GetConfiguredAudienceModelPolicyResult& WithConfiguredAudienceModelArn(ConfiguredAudienceModelArnT&& value) {
    SetConfiguredAudienceModelArn(std::forward<ConfiguredAudienceModelArnT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The configured audience model policy. This is a JSON IAM resource policy.</p>
   */
  inline const Aws::String& GetConfiguredAudienceModelPolicy() const { return m_configuredAudienceModelPolicy; }
  template <typename ConfiguredAudienceModelPolicyT = Aws::String>
  void SetConfiguredAudienceModelPolicy(ConfiguredAudienceModelPolicyT&& value) {
    m_configuredAudienceModelPolicyHasBeenSet = true;
    m_configuredAudienceModelPolicy = std::forward<ConfiguredAudienceModelPolicyT>(value);
  }
  template <typename ConfiguredAudienceModelPolicyT = Aws::String>
  GetConfiguredAudienceModelPolicyResult& WithConfiguredAudienceModelPolicy(ConfiguredAudienceModelPolicyT&& value) {
    SetConfiguredAudienceModelPolicy(std::forward<ConfiguredAudienceModelPolicyT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A cryptographic hash of the contents of the policy used to prevent unexpected
   * concurrent modification of the policy.</p>
   */
  inline const Aws::String& GetPolicyHash() const { return m_policyHash; }
  template <typename PolicyHashT = Aws::String>
  void SetPolicyHash(PolicyHashT&& value) {
    m_policyHashHasBeenSet = true;
    m_policyHash = std::forward<PolicyHashT>(value);
  }
  template <typename PolicyHashT = Aws::String>
  GetConfiguredAudienceModelPolicyResult& WithPolicyHash(PolicyHashT&& value) {
    SetPolicyHash(std::forward<PolicyHashT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  GetConfiguredAudienceModelPolicyResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_configuredAudienceModelArn;

  Aws::String m_configuredAudienceModelPolicy;

  Aws::String m_policyHash;

  Aws::String m_requestId;
  bool m_configuredAudienceModelArnHasBeenSet = false;
  bool m_configuredAudienceModelPolicyHasBeenSet = false;
  bool m_policyHashHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace CleanRoomsML
}  // namespace Aws
