/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/connectparticipant/ConnectParticipant_EXPORTS.h>
#include <aws/connectparticipant/model/AudioFeatures.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace ConnectParticipant {
namespace Model {

/**
 * <p>The configuration settings of the features available to a
 * meeting.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/connectparticipant-2018-09-07/MeetingFeaturesConfiguration">AWS
 * API Reference</a></p>
 */
class MeetingFeaturesConfiguration {
 public:
  AWS_CONNECTPARTICIPANT_API MeetingFeaturesConfiguration() = default;
  AWS_CONNECTPARTICIPANT_API MeetingFeaturesConfiguration(Aws::Utils::Json::JsonView jsonValue);
  AWS_CONNECTPARTICIPANT_API MeetingFeaturesConfiguration& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_CONNECTPARTICIPANT_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * <p>The configuration settings for the audio features available to a meeting.</p>
   */
  inline const AudioFeatures& GetAudio() const { return m_audio; }
  inline bool AudioHasBeenSet() const { return m_audioHasBeenSet; }
  template <typename AudioT = AudioFeatures>
  void SetAudio(AudioT&& value) {
    m_audioHasBeenSet = true;
    m_audio = std::forward<AudioT>(value);
  }
  template <typename AudioT = AudioFeatures>
  MeetingFeaturesConfiguration& WithAudio(AudioT&& value) {
    SetAudio(std::forward<AudioT>(value));
    return *this;
  }
  ///@}
 private:
  AudioFeatures m_audio;
  bool m_audioHasBeenSet = false;
};

}  // namespace Model
}  // namespace ConnectParticipant
}  // namespace Aws
