/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/chime/ChimeRequest.h>
#include <aws/chime/Chime_EXPORTS.h>
#include <aws/chime/model/PhoneNumberProductType.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Chime {
namespace Model {

/**
 */
class UpdatePhoneNumberRequest : public ChimeRequest {
 public:
  AWS_CHIME_API UpdatePhoneNumberRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "UpdatePhoneNumber"; }

  AWS_CHIME_API Aws::String SerializePayload() const override;

  ///@{
  /**
   * <p>The phone number ID.</p>
   */
  inline const Aws::String& GetPhoneNumberId() const { return m_phoneNumberId; }
  inline bool PhoneNumberIdHasBeenSet() const { return m_phoneNumberIdHasBeenSet; }
  template <typename PhoneNumberIdT = Aws::String>
  void SetPhoneNumberId(PhoneNumberIdT&& value) {
    m_phoneNumberIdHasBeenSet = true;
    m_phoneNumberId = std::forward<PhoneNumberIdT>(value);
  }
  template <typename PhoneNumberIdT = Aws::String>
  UpdatePhoneNumberRequest& WithPhoneNumberId(PhoneNumberIdT&& value) {
    SetPhoneNumberId(std::forward<PhoneNumberIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The product type.</p>
   */
  inline PhoneNumberProductType GetProductType() const { return m_productType; }
  inline bool ProductTypeHasBeenSet() const { return m_productTypeHasBeenSet; }
  inline void SetProductType(PhoneNumberProductType value) {
    m_productTypeHasBeenSet = true;
    m_productType = value;
  }
  inline UpdatePhoneNumberRequest& WithProductType(PhoneNumberProductType value) {
    SetProductType(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The outbound calling name associated with the phone number.</p>
   */
  inline const Aws::String& GetCallingName() const { return m_callingName; }
  inline bool CallingNameHasBeenSet() const { return m_callingNameHasBeenSet; }
  template <typename CallingNameT = Aws::String>
  void SetCallingName(CallingNameT&& value) {
    m_callingNameHasBeenSet = true;
    m_callingName = std::forward<CallingNameT>(value);
  }
  template <typename CallingNameT = Aws::String>
  UpdatePhoneNumberRequest& WithCallingName(CallingNameT&& value) {
    SetCallingName(std::forward<CallingNameT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_phoneNumberId;

  PhoneNumberProductType m_productType{PhoneNumberProductType::NOT_SET};

  Aws::String m_callingName;
  bool m_phoneNumberIdHasBeenSet = false;
  bool m_productTypeHasBeenSet = false;
  bool m_callingNameHasBeenSet = false;
};

}  // namespace Model
}  // namespace Chime
}  // namespace Aws
