/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/apprunner/AppRunner_EXPORTS.h>
#include <aws/apprunner/model/ServiceSummary.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace AppRunner {
namespace Model {
class ListServicesResult {
 public:
  AWS_APPRUNNER_API ListServicesResult() = default;
  AWS_APPRUNNER_API ListServicesResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_APPRUNNER_API ListServicesResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>A list of service summary information records. In a paginated request, the
   * request returns up to <code>MaxResults</code> records for each call.</p>
   */
  inline const Aws::Vector<ServiceSummary>& GetServiceSummaryList() const { return m_serviceSummaryList; }
  template <typename ServiceSummaryListT = Aws::Vector<ServiceSummary>>
  void SetServiceSummaryList(ServiceSummaryListT&& value) {
    m_serviceSummaryListHasBeenSet = true;
    m_serviceSummaryList = std::forward<ServiceSummaryListT>(value);
  }
  template <typename ServiceSummaryListT = Aws::Vector<ServiceSummary>>
  ListServicesResult& WithServiceSummaryList(ServiceSummaryListT&& value) {
    SetServiceSummaryList(std::forward<ServiceSummaryListT>(value));
    return *this;
  }
  template <typename ServiceSummaryListT = ServiceSummary>
  ListServicesResult& AddServiceSummaryList(ServiceSummaryListT&& value) {
    m_serviceSummaryListHasBeenSet = true;
    m_serviceSummaryList.emplace_back(std::forward<ServiceSummaryListT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The token that you can pass in a subsequent request to get the next result
   * page. It's returned in a paginated request.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  ListServicesResult& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  ListServicesResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<ServiceSummary> m_serviceSummaryList;

  Aws::String m_nextToken;

  Aws::String m_requestId;
  bool m_serviceSummaryListHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace AppRunner
}  // namespace Aws
