/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/athena/AthenaRequest.h>
#include <aws/athena/Athena_EXPORTS.h>
#include <aws/athena/model/ExecutorState.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Athena {
namespace Model {

/**
 */
class ListExecutorsRequest : public AthenaRequest {
 public:
  AWS_ATHENA_API ListExecutorsRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "ListExecutors"; }

  AWS_ATHENA_API Aws::String SerializePayload() const override;

  AWS_ATHENA_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>The session ID.</p>
   */
  inline const Aws::String& GetSessionId() const { return m_sessionId; }
  inline bool SessionIdHasBeenSet() const { return m_sessionIdHasBeenSet; }
  template <typename SessionIdT = Aws::String>
  void SetSessionId(SessionIdT&& value) {
    m_sessionIdHasBeenSet = true;
    m_sessionId = std::forward<SessionIdT>(value);
  }
  template <typename SessionIdT = Aws::String>
  ListExecutorsRequest& WithSessionId(SessionIdT&& value) {
    SetSessionId(std::forward<SessionIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A filter for a specific executor state. A description of each state
   * follows.</p> <p> <code>CREATING</code> - The executor is being started,
   * including acquiring resources.</p> <p> <code>CREATED</code> - The executor has
   * been started.</p> <p> <code>REGISTERED</code> - The executor has been
   * registered.</p> <p> <code>TERMINATING</code> - The executor is in the process of
   * shutting down.</p> <p> <code>TERMINATED</code> - The executor is no longer
   * running.</p> <p> <code>FAILED</code> - Due to a failure, the executor is no
   * longer running.</p>
   */
  inline ExecutorState GetExecutorStateFilter() const { return m_executorStateFilter; }
  inline bool ExecutorStateFilterHasBeenSet() const { return m_executorStateFilterHasBeenSet; }
  inline void SetExecutorStateFilter(ExecutorState value) {
    m_executorStateFilterHasBeenSet = true;
    m_executorStateFilter = value;
  }
  inline ListExecutorsRequest& WithExecutorStateFilter(ExecutorState value) {
    SetExecutorStateFilter(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The maximum number of executors to return.</p>
   */
  inline int GetMaxResults() const { return m_maxResults; }
  inline bool MaxResultsHasBeenSet() const { return m_maxResultsHasBeenSet; }
  inline void SetMaxResults(int value) {
    m_maxResultsHasBeenSet = true;
    m_maxResults = value;
  }
  inline ListExecutorsRequest& WithMaxResults(int value) {
    SetMaxResults(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A token generated by the Athena service that specifies where to continue
   * pagination if a previous request was truncated. To obtain the next set of pages,
   * pass in the <code>NextToken</code> from the response object of the previous page
   * call.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  inline bool NextTokenHasBeenSet() const { return m_nextTokenHasBeenSet; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  ListExecutorsRequest& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_sessionId;

  ExecutorState m_executorStateFilter{ExecutorState::NOT_SET};

  int m_maxResults{0};

  Aws::String m_nextToken;
  bool m_sessionIdHasBeenSet = false;
  bool m_executorStateFilterHasBeenSet = false;
  bool m_maxResultsHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
};

}  // namespace Model
}  // namespace Athena
}  // namespace Aws
