/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/cloudsearch/CloudSearchRequest.h>
#include <aws/cloudsearch/CloudSearch_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace CloudSearch {
namespace Model {

/**
 * <p>Container for the parameters to the <code><a>DeleteIndexField</a></code>
 * operation. Specifies the name of the domain you want to update and the name of
 * the index field you want to delete.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/cloudsearch-2013-01-01/DeleteIndexFieldRequest">AWS
 * API Reference</a></p>
 */
class DeleteIndexFieldRequest : public CloudSearchRequest {
 public:
  AWS_CLOUDSEARCH_API DeleteIndexFieldRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "DeleteIndexField"; }

  AWS_CLOUDSEARCH_API Aws::String SerializePayload() const override;

 protected:
  AWS_CLOUDSEARCH_API void DumpBodyToUrl(Aws::Http::URI& uri) const override;

 public:
  ///@{

  inline const Aws::String& GetDomainName() const { return m_domainName; }
  inline bool DomainNameHasBeenSet() const { return m_domainNameHasBeenSet; }
  template <typename DomainNameT = Aws::String>
  void SetDomainName(DomainNameT&& value) {
    m_domainNameHasBeenSet = true;
    m_domainName = std::forward<DomainNameT>(value);
  }
  template <typename DomainNameT = Aws::String>
  DeleteIndexFieldRequest& WithDomainName(DomainNameT&& value) {
    SetDomainName(std::forward<DomainNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the index field your want to remove from the domain's indexing
   * options.</p>
   */
  inline const Aws::String& GetIndexFieldName() const { return m_indexFieldName; }
  inline bool IndexFieldNameHasBeenSet() const { return m_indexFieldNameHasBeenSet; }
  template <typename IndexFieldNameT = Aws::String>
  void SetIndexFieldName(IndexFieldNameT&& value) {
    m_indexFieldNameHasBeenSet = true;
    m_indexFieldName = std::forward<IndexFieldNameT>(value);
  }
  template <typename IndexFieldNameT = Aws::String>
  DeleteIndexFieldRequest& WithIndexFieldName(IndexFieldNameT&& value) {
    SetIndexFieldName(std::forward<IndexFieldNameT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_domainName;

  Aws::String m_indexFieldName;
  bool m_domainNameHasBeenSet = false;
  bool m_indexFieldNameHasBeenSet = false;
};

}  // namespace Model
}  // namespace CloudSearch
}  // namespace Aws
