/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/accessanalyzer/AccessAnalyzerRequest.h>
#include <aws/accessanalyzer/AccessAnalyzer_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace AccessAnalyzer {
namespace Model {

/**
 * <p>Retrieves an archive rule.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/accessanalyzer-2019-11-01/GetArchiveRuleRequest">AWS
 * API Reference</a></p>
 */
class GetArchiveRuleRequest : public AccessAnalyzerRequest {
 public:
  AWS_ACCESSANALYZER_API GetArchiveRuleRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "GetArchiveRule"; }

  AWS_ACCESSANALYZER_API Aws::String SerializePayload() const override;

  ///@{
  /**
   * <p>The name of the analyzer to retrieve rules from.</p>
   */
  inline const Aws::String& GetAnalyzerName() const { return m_analyzerName; }
  inline bool AnalyzerNameHasBeenSet() const { return m_analyzerNameHasBeenSet; }
  template <typename AnalyzerNameT = Aws::String>
  void SetAnalyzerName(AnalyzerNameT&& value) {
    m_analyzerNameHasBeenSet = true;
    m_analyzerName = std::forward<AnalyzerNameT>(value);
  }
  template <typename AnalyzerNameT = Aws::String>
  GetArchiveRuleRequest& WithAnalyzerName(AnalyzerNameT&& value) {
    SetAnalyzerName(std::forward<AnalyzerNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the rule to retrieve.</p>
   */
  inline const Aws::String& GetRuleName() const { return m_ruleName; }
  inline bool RuleNameHasBeenSet() const { return m_ruleNameHasBeenSet; }
  template <typename RuleNameT = Aws::String>
  void SetRuleName(RuleNameT&& value) {
    m_ruleNameHasBeenSet = true;
    m_ruleName = std::forward<RuleNameT>(value);
  }
  template <typename RuleNameT = Aws::String>
  GetArchiveRuleRequest& WithRuleName(RuleNameT&& value) {
    SetRuleName(std::forward<RuleNameT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_analyzerName;

  Aws::String m_ruleName;
  bool m_analyzerNameHasBeenSet = false;
  bool m_ruleNameHasBeenSet = false;
};

}  // namespace Model
}  // namespace AccessAnalyzer
}  // namespace Aws
