/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/cloudformation/CloudFormation_EXPORTS.h>
#include <aws/cloudformation/model/ResponseMetadata.h>
#include <aws/cloudformation/model/StackEvent.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Xml {
class XmlDocument;
}  // namespace Xml
}  // namespace Utils
namespace CloudFormation {
namespace Model {
/**
 * <p>The output for a <a>DescribeStackEvents</a> action.</p><p><h3>See Also:</h3>
 * <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/cloudformation-2010-05-15/DescribeStackEventsOutput">AWS
 * API Reference</a></p>
 */
class DescribeStackEventsResult {
 public:
  AWS_CLOUDFORMATION_API DescribeStackEventsResult() = default;
  AWS_CLOUDFORMATION_API DescribeStackEventsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);
  AWS_CLOUDFORMATION_API DescribeStackEventsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Xml::XmlDocument>& result);

  ///@{
  /**
   * <p>A list of <code>StackEvents</code> structures.</p>
   */
  inline const Aws::Vector<StackEvent>& GetStackEvents() const { return m_stackEvents; }
  template <typename StackEventsT = Aws::Vector<StackEvent>>
  void SetStackEvents(StackEventsT&& value) {
    m_stackEventsHasBeenSet = true;
    m_stackEvents = std::forward<StackEventsT>(value);
  }
  template <typename StackEventsT = Aws::Vector<StackEvent>>
  DescribeStackEventsResult& WithStackEvents(StackEventsT&& value) {
    SetStackEvents(std::forward<StackEventsT>(value));
    return *this;
  }
  template <typename StackEventsT = StackEvent>
  DescribeStackEventsResult& AddStackEvents(StackEventsT&& value) {
    m_stackEventsHasBeenSet = true;
    m_stackEvents.emplace_back(std::forward<StackEventsT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>If the output exceeds 1 MB in size, a string that identifies the next page of
   * events. If no additional page exists, this value is null.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  DescribeStackEventsResult& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const ResponseMetadata& GetResponseMetadata() const { return m_responseMetadata; }
  template <typename ResponseMetadataT = ResponseMetadata>
  void SetResponseMetadata(ResponseMetadataT&& value) {
    m_responseMetadataHasBeenSet = true;
    m_responseMetadata = std::forward<ResponseMetadataT>(value);
  }
  template <typename ResponseMetadataT = ResponseMetadata>
  DescribeStackEventsResult& WithResponseMetadata(ResponseMetadataT&& value) {
    SetResponseMetadata(std::forward<ResponseMetadataT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<StackEvent> m_stackEvents;

  Aws::String m_nextToken;

  ResponseMetadata m_responseMetadata;
  bool m_stackEventsHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_responseMetadataHasBeenSet = false;
};

}  // namespace Model
}  // namespace CloudFormation
}  // namespace Aws
