/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/appmesh/AppMesh_EXPORTS.h>
#include <aws/core/utils/DateTime.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace AppMesh {
namespace Model {

/**
 * <p>An object that represents a virtual node returned by a list
 * operation.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/appmesh-2019-01-25/VirtualNodeRef">AWS
 * API Reference</a></p>
 */
class VirtualNodeRef {
 public:
  AWS_APPMESH_API VirtualNodeRef() = default;
  AWS_APPMESH_API VirtualNodeRef(Aws::Utils::Json::JsonView jsonValue);
  AWS_APPMESH_API VirtualNodeRef& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_APPMESH_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{
  /**
   * <p>The full Amazon Resource Name (ARN) for the virtual node.</p>
   */
  inline const Aws::String& GetArn() const { return m_arn; }
  inline bool ArnHasBeenSet() const { return m_arnHasBeenSet; }
  template <typename ArnT = Aws::String>
  void SetArn(ArnT&& value) {
    m_arnHasBeenSet = true;
    m_arn = std::forward<ArnT>(value);
  }
  template <typename ArnT = Aws::String>
  VirtualNodeRef& WithArn(ArnT&& value) {
    SetArn(std::forward<ArnT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The Unix epoch timestamp in seconds for when the resource was created.</p>
   */
  inline const Aws::Utils::DateTime& GetCreatedAt() const { return m_createdAt; }
  inline bool CreatedAtHasBeenSet() const { return m_createdAtHasBeenSet; }
  template <typename CreatedAtT = Aws::Utils::DateTime>
  void SetCreatedAt(CreatedAtT&& value) {
    m_createdAtHasBeenSet = true;
    m_createdAt = std::forward<CreatedAtT>(value);
  }
  template <typename CreatedAtT = Aws::Utils::DateTime>
  VirtualNodeRef& WithCreatedAt(CreatedAtT&& value) {
    SetCreatedAt(std::forward<CreatedAtT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The Unix epoch timestamp in seconds for when the resource was last
   * updated.</p>
   */
  inline const Aws::Utils::DateTime& GetLastUpdatedAt() const { return m_lastUpdatedAt; }
  inline bool LastUpdatedAtHasBeenSet() const { return m_lastUpdatedAtHasBeenSet; }
  template <typename LastUpdatedAtT = Aws::Utils::DateTime>
  void SetLastUpdatedAt(LastUpdatedAtT&& value) {
    m_lastUpdatedAtHasBeenSet = true;
    m_lastUpdatedAt = std::forward<LastUpdatedAtT>(value);
  }
  template <typename LastUpdatedAtT = Aws::Utils::DateTime>
  VirtualNodeRef& WithLastUpdatedAt(LastUpdatedAtT&& value) {
    SetLastUpdatedAt(std::forward<LastUpdatedAtT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the service mesh that the virtual node resides in.</p>
   */
  inline const Aws::String& GetMeshName() const { return m_meshName; }
  inline bool MeshNameHasBeenSet() const { return m_meshNameHasBeenSet; }
  template <typename MeshNameT = Aws::String>
  void SetMeshName(MeshNameT&& value) {
    m_meshNameHasBeenSet = true;
    m_meshName = std::forward<MeshNameT>(value);
  }
  template <typename MeshNameT = Aws::String>
  VirtualNodeRef& WithMeshName(MeshNameT&& value) {
    SetMeshName(std::forward<MeshNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The Amazon Web Services IAM account ID of the service mesh owner. If the
   * account ID is not your own, then it's the ID of the account that shared the mesh
   * with your account. For more information about mesh sharing, see <a
   * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
   * with shared meshes</a>.</p>
   */
  inline const Aws::String& GetMeshOwner() const { return m_meshOwner; }
  inline bool MeshOwnerHasBeenSet() const { return m_meshOwnerHasBeenSet; }
  template <typename MeshOwnerT = Aws::String>
  void SetMeshOwner(MeshOwnerT&& value) {
    m_meshOwnerHasBeenSet = true;
    m_meshOwner = std::forward<MeshOwnerT>(value);
  }
  template <typename MeshOwnerT = Aws::String>
  VirtualNodeRef& WithMeshOwner(MeshOwnerT&& value) {
    SetMeshOwner(std::forward<MeshOwnerT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The Amazon Web Services IAM account ID of the resource owner. If the account
   * ID is not your own, then it's the ID of the mesh owner or of another account
   * that the mesh is shared with. For more information about mesh sharing, see <a
   * href="https://docs.aws.amazon.com/app-mesh/latest/userguide/sharing.html">Working
   * with shared meshes</a>.</p>
   */
  inline const Aws::String& GetResourceOwner() const { return m_resourceOwner; }
  inline bool ResourceOwnerHasBeenSet() const { return m_resourceOwnerHasBeenSet; }
  template <typename ResourceOwnerT = Aws::String>
  void SetResourceOwner(ResourceOwnerT&& value) {
    m_resourceOwnerHasBeenSet = true;
    m_resourceOwner = std::forward<ResourceOwnerT>(value);
  }
  template <typename ResourceOwnerT = Aws::String>
  VirtualNodeRef& WithResourceOwner(ResourceOwnerT&& value) {
    SetResourceOwner(std::forward<ResourceOwnerT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The version of the resource. Resources are created at version 1, and this
   * version is incremented each time that they're updated.</p>
   */
  inline long long GetVersion() const { return m_version; }
  inline bool VersionHasBeenSet() const { return m_versionHasBeenSet; }
  inline void SetVersion(long long value) {
    m_versionHasBeenSet = true;
    m_version = value;
  }
  inline VirtualNodeRef& WithVersion(long long value) {
    SetVersion(value);
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the virtual node.</p>
   */
  inline const Aws::String& GetVirtualNodeName() const { return m_virtualNodeName; }
  inline bool VirtualNodeNameHasBeenSet() const { return m_virtualNodeNameHasBeenSet; }
  template <typename VirtualNodeNameT = Aws::String>
  void SetVirtualNodeName(VirtualNodeNameT&& value) {
    m_virtualNodeNameHasBeenSet = true;
    m_virtualNodeName = std::forward<VirtualNodeNameT>(value);
  }
  template <typename VirtualNodeNameT = Aws::String>
  VirtualNodeRef& WithVirtualNodeName(VirtualNodeNameT&& value) {
    SetVirtualNodeName(std::forward<VirtualNodeNameT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_arn;

  Aws::Utils::DateTime m_createdAt{};

  Aws::Utils::DateTime m_lastUpdatedAt{};

  Aws::String m_meshName;

  Aws::String m_meshOwner;

  Aws::String m_resourceOwner;

  long long m_version{0};

  Aws::String m_virtualNodeName;
  bool m_arnHasBeenSet = false;
  bool m_createdAtHasBeenSet = false;
  bool m_lastUpdatedAtHasBeenSet = false;
  bool m_meshNameHasBeenSet = false;
  bool m_meshOwnerHasBeenSet = false;
  bool m_resourceOwnerHasBeenSet = false;
  bool m_versionHasBeenSet = false;
  bool m_virtualNodeNameHasBeenSet = false;
};

}  // namespace Model
}  // namespace AppMesh
}  // namespace Aws
