/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/backupsearch/BackupSearch_EXPORTS.h>
#include <aws/backupsearch/model/SearchJobSummary.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace BackupSearch {
namespace Model {
class ListSearchJobsResult {
 public:
  AWS_BACKUPSEARCH_API ListSearchJobsResult() = default;
  AWS_BACKUPSEARCH_API ListSearchJobsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_BACKUPSEARCH_API ListSearchJobsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The search jobs among the list, with details of the returned search jobs.</p>
   */
  inline const Aws::Vector<SearchJobSummary>& GetSearchJobs() const { return m_searchJobs; }
  template <typename SearchJobsT = Aws::Vector<SearchJobSummary>>
  void SetSearchJobs(SearchJobsT&& value) {
    m_searchJobsHasBeenSet = true;
    m_searchJobs = std::forward<SearchJobsT>(value);
  }
  template <typename SearchJobsT = Aws::Vector<SearchJobSummary>>
  ListSearchJobsResult& WithSearchJobs(SearchJobsT&& value) {
    SetSearchJobs(std::forward<SearchJobsT>(value));
    return *this;
  }
  template <typename SearchJobsT = SearchJobSummary>
  ListSearchJobsResult& AddSearchJobs(SearchJobsT&& value) {
    m_searchJobsHasBeenSet = true;
    m_searchJobs.emplace_back(std::forward<SearchJobsT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The next item following a partial list of returned backups included in a
   * search job.</p> <p>For example, if a request is made to return
   * <code>MaxResults</code> number of backups, <code>NextToken</code> allows you to
   * return more items in your list starting at the location pointed to by the next
   * token.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  ListSearchJobsResult& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  ListSearchJobsResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::Vector<SearchJobSummary> m_searchJobs;

  Aws::String m_nextToken;

  Aws::String m_requestId;
  bool m_searchJobsHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace BackupSearch
}  // namespace Aws
