/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/codecatalyst/CodeCatalyst_EXPORTS.h>
#include <aws/core/utils/DateTime.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace CodeCatalyst {
namespace Model {
class CreateSourceRepositoryBranchResult {
 public:
  AWS_CODECATALYST_API CreateSourceRepositoryBranchResult() = default;
  AWS_CODECATALYST_API CreateSourceRepositoryBranchResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_CODECATALYST_API CreateSourceRepositoryBranchResult& operator=(
      const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The Git reference name of the branch.</p>
   */
  inline const Aws::String& GetRef() const { return m_ref; }
  template <typename RefT = Aws::String>
  void SetRef(RefT&& value) {
    m_refHasBeenSet = true;
    m_ref = std::forward<RefT>(value);
  }
  template <typename RefT = Aws::String>
  CreateSourceRepositoryBranchResult& WithRef(RefT&& value) {
    SetRef(std::forward<RefT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name of the newly created branch.</p>
   */
  inline const Aws::String& GetName() const { return m_name; }
  template <typename NameT = Aws::String>
  void SetName(NameT&& value) {
    m_nameHasBeenSet = true;
    m_name = std::forward<NameT>(value);
  }
  template <typename NameT = Aws::String>
  CreateSourceRepositoryBranchResult& WithName(NameT&& value) {
    SetName(std::forward<NameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The time the branch was last updated, in coordinated universal time (UTC)
   * timestamp format as specified in <a
   * href="https://www.rfc-editor.org/rfc/rfc3339#section-5.6">RFC 3339</a>.</p>
   */
  inline const Aws::Utils::DateTime& GetLastUpdatedTime() const { return m_lastUpdatedTime; }
  template <typename LastUpdatedTimeT = Aws::Utils::DateTime>
  void SetLastUpdatedTime(LastUpdatedTimeT&& value) {
    m_lastUpdatedTimeHasBeenSet = true;
    m_lastUpdatedTime = std::forward<LastUpdatedTimeT>(value);
  }
  template <typename LastUpdatedTimeT = Aws::Utils::DateTime>
  CreateSourceRepositoryBranchResult& WithLastUpdatedTime(LastUpdatedTimeT&& value) {
    SetLastUpdatedTime(std::forward<LastUpdatedTimeT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The commit ID of the tip of the newly created branch.</p>
   */
  inline const Aws::String& GetHeadCommitId() const { return m_headCommitId; }
  template <typename HeadCommitIdT = Aws::String>
  void SetHeadCommitId(HeadCommitIdT&& value) {
    m_headCommitIdHasBeenSet = true;
    m_headCommitId = std::forward<HeadCommitIdT>(value);
  }
  template <typename HeadCommitIdT = Aws::String>
  CreateSourceRepositoryBranchResult& WithHeadCommitId(HeadCommitIdT&& value) {
    SetHeadCommitId(std::forward<HeadCommitIdT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  CreateSourceRepositoryBranchResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_ref;

  Aws::String m_name;

  Aws::Utils::DateTime m_lastUpdatedTime{};

  Aws::String m_headCommitId;

  Aws::String m_requestId;
  bool m_refHasBeenSet = false;
  bool m_nameHasBeenSet = false;
  bool m_lastUpdatedTimeHasBeenSet = false;
  bool m_headCommitIdHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace CodeCatalyst
}  // namespace Aws
