/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/apigateway/APIGateway_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Utils {
namespace Json {
class JsonValue;
class JsonView;
}  // namespace Json
}  // namespace Utils
namespace APIGateway {
namespace Model {

/**
 * <p>The request exceeded the rate limit. Retry after the specified time
 * period.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/apigateway-2015-07-09/LimitExceededException">AWS
 * API Reference</a></p>
 */
class LimitExceededException {
 public:
  AWS_APIGATEWAY_API LimitExceededException() = default;
  AWS_APIGATEWAY_API LimitExceededException(Aws::Utils::Json::JsonView jsonValue);
  AWS_APIGATEWAY_API LimitExceededException& operator=(Aws::Utils::Json::JsonView jsonValue);
  AWS_APIGATEWAY_API Aws::Utils::Json::JsonValue Jsonize() const;

  ///@{

  inline const Aws::String& GetRetryAfterSeconds() const { return m_retryAfterSeconds; }
  inline bool RetryAfterSecondsHasBeenSet() const { return m_retryAfterSecondsHasBeenSet; }
  template <typename RetryAfterSecondsT = Aws::String>
  void SetRetryAfterSeconds(RetryAfterSecondsT&& value) {
    m_retryAfterSecondsHasBeenSet = true;
    m_retryAfterSeconds = std::forward<RetryAfterSecondsT>(value);
  }
  template <typename RetryAfterSecondsT = Aws::String>
  LimitExceededException& WithRetryAfterSeconds(RetryAfterSecondsT&& value) {
    SetRetryAfterSeconds(std::forward<RetryAfterSecondsT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetMessage() const { return m_message; }
  inline bool MessageHasBeenSet() const { return m_messageHasBeenSet; }
  template <typename MessageT = Aws::String>
  void SetMessage(MessageT&& value) {
    m_messageHasBeenSet = true;
    m_message = std::forward<MessageT>(value);
  }
  template <typename MessageT = Aws::String>
  LimitExceededException& WithMessage(MessageT&& value) {
    SetMessage(std::forward<MessageT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_retryAfterSeconds;

  Aws::String m_message;
  bool m_retryAfterSecondsHasBeenSet = false;
  bool m_messageHasBeenSet = false;
};

}  // namespace Model
}  // namespace APIGateway
}  // namespace Aws
