/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/cloudfront/CloudFrontRequest.h>
#include <aws/cloudfront/CloudFront_EXPORTS.h>
#include <aws/cloudfront/model/CloudFrontOriginAccessIdentityConfig.h>

#include <utility>

namespace Aws {
namespace CloudFront {
namespace Model {

/**
 * <p>The request to create a new origin access identity (OAI). An origin access
 * identity is a special CloudFront user that you can associate with Amazon S3
 * origins, so that you can secure all or just some of your Amazon S3 content. For
 * more information, see <a
 * href="https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/private-content-restricting-access-to-s3.html">
 * Restricting Access to Amazon S3 Content by Using an Origin Access Identity</a>
 * in the <i>Amazon CloudFront Developer Guide</i>.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/cloudfront-2020-05-31/CreateCloudFrontOriginAccessIdentityRequest">AWS
 * API Reference</a></p>
 */
class CreateCloudFrontOriginAccessIdentity2020_05_31Request : public CloudFrontRequest {
 public:
  AWS_CLOUDFRONT_API CreateCloudFrontOriginAccessIdentity2020_05_31Request() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "CreateCloudFrontOriginAccessIdentity"; }

  AWS_CLOUDFRONT_API Aws::String SerializePayload() const override;

  ///@{
  /**
   * <p>The current configuration information for the identity.</p>
   */
  inline const CloudFrontOriginAccessIdentityConfig& GetCloudFrontOriginAccessIdentityConfig() const {
    return m_cloudFrontOriginAccessIdentityConfig;
  }
  inline bool CloudFrontOriginAccessIdentityConfigHasBeenSet() const { return m_cloudFrontOriginAccessIdentityConfigHasBeenSet; }
  template <typename CloudFrontOriginAccessIdentityConfigT = CloudFrontOriginAccessIdentityConfig>
  void SetCloudFrontOriginAccessIdentityConfig(CloudFrontOriginAccessIdentityConfigT&& value) {
    m_cloudFrontOriginAccessIdentityConfigHasBeenSet = true;
    m_cloudFrontOriginAccessIdentityConfig = std::forward<CloudFrontOriginAccessIdentityConfigT>(value);
  }
  template <typename CloudFrontOriginAccessIdentityConfigT = CloudFrontOriginAccessIdentityConfig>
  CreateCloudFrontOriginAccessIdentity2020_05_31Request& WithCloudFrontOriginAccessIdentityConfig(
      CloudFrontOriginAccessIdentityConfigT&& value) {
    SetCloudFrontOriginAccessIdentityConfig(std::forward<CloudFrontOriginAccessIdentityConfigT>(value));
    return *this;
  }
  ///@}
 private:
  CloudFrontOriginAccessIdentityConfig m_cloudFrontOriginAccessIdentityConfig;
  bool m_cloudFrontOriginAccessIdentityConfigHasBeenSet = false;
};

}  // namespace Model
}  // namespace CloudFront
}  // namespace Aws
