/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/amplify/AmplifyRequest.h>
#include <aws/amplify/Amplify_EXPORTS.h>
#include <aws/core/utils/memory/stl/AWSString.h>

#include <utility>

namespace Aws {
namespace Amplify {
namespace Model {

/**
 * <p>The request structure for the update webhook request. </p><p><h3>See
 * Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/amplify-2017-07-25/UpdateWebhookRequest">AWS
 * API Reference</a></p>
 */
class UpdateWebhookRequest : public AmplifyRequest {
 public:
  AWS_AMPLIFY_API UpdateWebhookRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "UpdateWebhook"; }

  AWS_AMPLIFY_API Aws::String SerializePayload() const override;

  ///@{
  /**
   * <p>The unique ID for a webhook. </p>
   */
  inline const Aws::String& GetWebhookId() const { return m_webhookId; }
  inline bool WebhookIdHasBeenSet() const { return m_webhookIdHasBeenSet; }
  template <typename WebhookIdT = Aws::String>
  void SetWebhookId(WebhookIdT&& value) {
    m_webhookIdHasBeenSet = true;
    m_webhookId = std::forward<WebhookIdT>(value);
  }
  template <typename WebhookIdT = Aws::String>
  UpdateWebhookRequest& WithWebhookId(WebhookIdT&& value) {
    SetWebhookId(std::forward<WebhookIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The name for a branch that is part of an Amplify app. </p>
   */
  inline const Aws::String& GetBranchName() const { return m_branchName; }
  inline bool BranchNameHasBeenSet() const { return m_branchNameHasBeenSet; }
  template <typename BranchNameT = Aws::String>
  void SetBranchName(BranchNameT&& value) {
    m_branchNameHasBeenSet = true;
    m_branchName = std::forward<BranchNameT>(value);
  }
  template <typename BranchNameT = Aws::String>
  UpdateWebhookRequest& WithBranchName(BranchNameT&& value) {
    SetBranchName(std::forward<BranchNameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The description for a webhook. </p>
   */
  inline const Aws::String& GetDescription() const { return m_description; }
  inline bool DescriptionHasBeenSet() const { return m_descriptionHasBeenSet; }
  template <typename DescriptionT = Aws::String>
  void SetDescription(DescriptionT&& value) {
    m_descriptionHasBeenSet = true;
    m_description = std::forward<DescriptionT>(value);
  }
  template <typename DescriptionT = Aws::String>
  UpdateWebhookRequest& WithDescription(DescriptionT&& value) {
    SetDescription(std::forward<DescriptionT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_webhookId;

  Aws::String m_branchName;

  Aws::String m_description;
  bool m_webhookIdHasBeenSet = false;
  bool m_branchNameHasBeenSet = false;
  bool m_descriptionHasBeenSet = false;
};

}  // namespace Model
}  // namespace Amplify
}  // namespace Aws
