/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/athena/Athena_EXPORTS.h>
#include <aws/athena/model/ExecutorsSummary.h>
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>

#include <utility>

namespace Aws {
template <typename RESULT_TYPE>
class AmazonWebServiceResult;

namespace Utils {
namespace Json {
class JsonValue;
}  // namespace Json
}  // namespace Utils
namespace Athena {
namespace Model {
class ListExecutorsResult {
 public:
  AWS_ATHENA_API ListExecutorsResult() = default;
  AWS_ATHENA_API ListExecutorsResult(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);
  AWS_ATHENA_API ListExecutorsResult& operator=(const Aws::AmazonWebServiceResult<Aws::Utils::Json::JsonValue>& result);

  ///@{
  /**
   * <p>The session ID.</p>
   */
  inline const Aws::String& GetSessionId() const { return m_sessionId; }
  template <typename SessionIdT = Aws::String>
  void SetSessionId(SessionIdT&& value) {
    m_sessionIdHasBeenSet = true;
    m_sessionId = std::forward<SessionIdT>(value);
  }
  template <typename SessionIdT = Aws::String>
  ListExecutorsResult& WithSessionId(SessionIdT&& value) {
    SetSessionId(std::forward<SessionIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A token generated by the Athena service that specifies where to continue
   * pagination if a previous request was truncated. To obtain the next set of pages,
   * pass in the <code>NextToken</code> from the response object of the previous page
   * call.</p>
   */
  inline const Aws::String& GetNextToken() const { return m_nextToken; }
  template <typename NextTokenT = Aws::String>
  void SetNextToken(NextTokenT&& value) {
    m_nextTokenHasBeenSet = true;
    m_nextToken = std::forward<NextTokenT>(value);
  }
  template <typename NextTokenT = Aws::String>
  ListExecutorsResult& WithNextToken(NextTokenT&& value) {
    SetNextToken(std::forward<NextTokenT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>Contains summary information about the executor.</p>
   */
  inline const Aws::Vector<ExecutorsSummary>& GetExecutorsSummary() const { return m_executorsSummary; }
  template <typename ExecutorsSummaryT = Aws::Vector<ExecutorsSummary>>
  void SetExecutorsSummary(ExecutorsSummaryT&& value) {
    m_executorsSummaryHasBeenSet = true;
    m_executorsSummary = std::forward<ExecutorsSummaryT>(value);
  }
  template <typename ExecutorsSummaryT = Aws::Vector<ExecutorsSummary>>
  ListExecutorsResult& WithExecutorsSummary(ExecutorsSummaryT&& value) {
    SetExecutorsSummary(std::forward<ExecutorsSummaryT>(value));
    return *this;
  }
  template <typename ExecutorsSummaryT = ExecutorsSummary>
  ListExecutorsResult& AddExecutorsSummary(ExecutorsSummaryT&& value) {
    m_executorsSummaryHasBeenSet = true;
    m_executorsSummary.emplace_back(std::forward<ExecutorsSummaryT>(value));
    return *this;
  }
  ///@}

  ///@{

  inline const Aws::String& GetRequestId() const { return m_requestId; }
  template <typename RequestIdT = Aws::String>
  void SetRequestId(RequestIdT&& value) {
    m_requestIdHasBeenSet = true;
    m_requestId = std::forward<RequestIdT>(value);
  }
  template <typename RequestIdT = Aws::String>
  ListExecutorsResult& WithRequestId(RequestIdT&& value) {
    SetRequestId(std::forward<RequestIdT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_sessionId;

  Aws::String m_nextToken;

  Aws::Vector<ExecutorsSummary> m_executorsSummary;

  Aws::String m_requestId;
  bool m_sessionIdHasBeenSet = false;
  bool m_nextTokenHasBeenSet = false;
  bool m_executorsSummaryHasBeenSet = false;
  bool m_requestIdHasBeenSet = false;
};

}  // namespace Model
}  // namespace Athena
}  // namespace Aws
