/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/core/utils/memory/stl/AWSString.h>
#include <aws/core/utils/memory/stl/AWSVector.h>
#include <aws/datapipeline/DataPipelineRequest.h>
#include <aws/datapipeline/DataPipeline_EXPORTS.h>
#include <aws/datapipeline/model/Tag.h>

#include <utility>

namespace Aws {
namespace DataPipeline {
namespace Model {

/**
 * <p>Contains the parameters for CreatePipeline.</p><p><h3>See Also:</h3>   <a
 * href="http://docs.aws.amazon.com/goto/WebAPI/datapipeline-2012-10-29/CreatePipelineInput">AWS
 * API Reference</a></p>
 */
class CreatePipelineRequest : public DataPipelineRequest {
 public:
  AWS_DATAPIPELINE_API CreatePipelineRequest() = default;

  // Service request name is the Operation name which will send this request out,
  // each operation should has unique request name, so that we can get operation's name from this request.
  // Note: this is not true for response, multiple operations may have the same response name,
  // so we can not get operation's name from response.
  inline virtual const char* GetServiceRequestName() const override { return "CreatePipeline"; }

  AWS_DATAPIPELINE_API Aws::String SerializePayload() const override;

  AWS_DATAPIPELINE_API Aws::Http::HeaderValueCollection GetRequestSpecificHeaders() const override;

  ///@{
  /**
   * <p>The name for the pipeline. You can use the same name for multiple pipelines
   * associated with your AWS account, because AWS Data Pipeline assigns each
   * pipeline a unique pipeline identifier.</p>
   */
  inline const Aws::String& GetName() const { return m_name; }
  inline bool NameHasBeenSet() const { return m_nameHasBeenSet; }
  template <typename NameT = Aws::String>
  void SetName(NameT&& value) {
    m_nameHasBeenSet = true;
    m_name = std::forward<NameT>(value);
  }
  template <typename NameT = Aws::String>
  CreatePipelineRequest& WithName(NameT&& value) {
    SetName(std::forward<NameT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A unique identifier. This identifier is not the same as the pipeline
   * identifier assigned by AWS Data Pipeline. You are responsible for defining the
   * format and ensuring the uniqueness of this identifier. You use this parameter to
   * ensure idempotency during repeated calls to <code>CreatePipeline</code>. For
   * example, if the first call to <code>CreatePipeline</code> does not succeed, you
   * can pass in the same unique identifier and pipeline name combination on a
   * subsequent call to <code>CreatePipeline</code>. <code>CreatePipeline</code>
   * ensures that if a pipeline already exists with the same name and unique
   * identifier, a new pipeline is not created. Instead, you'll receive the pipeline
   * identifier from the previous attempt. The uniqueness of the name and unique
   * identifier combination is scoped to the AWS account or IAM user credentials.</p>
   */
  inline const Aws::String& GetUniqueId() const { return m_uniqueId; }
  inline bool UniqueIdHasBeenSet() const { return m_uniqueIdHasBeenSet; }
  template <typename UniqueIdT = Aws::String>
  void SetUniqueId(UniqueIdT&& value) {
    m_uniqueIdHasBeenSet = true;
    m_uniqueId = std::forward<UniqueIdT>(value);
  }
  template <typename UniqueIdT = Aws::String>
  CreatePipelineRequest& WithUniqueId(UniqueIdT&& value) {
    SetUniqueId(std::forward<UniqueIdT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>The description for the pipeline.</p>
   */
  inline const Aws::String& GetDescription() const { return m_description; }
  inline bool DescriptionHasBeenSet() const { return m_descriptionHasBeenSet; }
  template <typename DescriptionT = Aws::String>
  void SetDescription(DescriptionT&& value) {
    m_descriptionHasBeenSet = true;
    m_description = std::forward<DescriptionT>(value);
  }
  template <typename DescriptionT = Aws::String>
  CreatePipelineRequest& WithDescription(DescriptionT&& value) {
    SetDescription(std::forward<DescriptionT>(value));
    return *this;
  }
  ///@}

  ///@{
  /**
   * <p>A list of tags to associate with the pipeline at creation. Tags let you
   * control access to pipelines. For more information, see <a
   * href="http://docs.aws.amazon.com/datapipeline/latest/DeveloperGuide/dp-control-access.html">Controlling
   * User Access to Pipelines</a> in the <i>AWS Data Pipeline Developer
   * Guide</i>.</p>
   */
  inline const Aws::Vector<Tag>& GetTags() const { return m_tags; }
  inline bool TagsHasBeenSet() const { return m_tagsHasBeenSet; }
  template <typename TagsT = Aws::Vector<Tag>>
  void SetTags(TagsT&& value) {
    m_tagsHasBeenSet = true;
    m_tags = std::forward<TagsT>(value);
  }
  template <typename TagsT = Aws::Vector<Tag>>
  CreatePipelineRequest& WithTags(TagsT&& value) {
    SetTags(std::forward<TagsT>(value));
    return *this;
  }
  template <typename TagsT = Tag>
  CreatePipelineRequest& AddTags(TagsT&& value) {
    m_tagsHasBeenSet = true;
    m_tags.emplace_back(std::forward<TagsT>(value));
    return *this;
  }
  ///@}
 private:
  Aws::String m_name;

  Aws::String m_uniqueId;

  Aws::String m_description;

  Aws::Vector<Tag> m_tags;
  bool m_nameHasBeenSet = false;
  bool m_uniqueIdHasBeenSet = false;
  bool m_descriptionHasBeenSet = false;
  bool m_tagsHasBeenSet = false;
};

}  // namespace Model
}  // namespace DataPipeline
}  // namespace Aws
